# fontman

[![PyPi Version](https://img.shields.io/pypi/v/fontman.svg?style=flat-square)](https://pypi.org/project/fontman)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/fontman.svg?style=flat-square)](https://pypi.org/pypi/fontman/)
[![GitHub stars](https://img.shields.io/github/stars/nschloe/fontman.svg?style=flat-square&logo=github&label=Stars&logoColor=white)](https://github.com/nschloe/fontman)
[![PyPi downloads](https://img.shields.io/pypi/dm/fontman.svg?style=flat-square)](https://pypistats.org/packages/fontman)

[![gh-actions](https://img.shields.io/github/workflow/status/nschloe/fontman/ci?style=flat-square)](https://github.com/nschloe/fontman/actions?query=workflow%3Aci)
[![CircleCI](https://img.shields.io/circleci/project/github/nschloe/fontman/main.svg?style=flat-square)](https://circleci.com/gh/nschloe/fontman/tree/main)
[![travis](https://img.shields.io/travis/nschloe/fontman.svg?style=flat-square)](https://travis-ci.org/nschloe/fontman)
[![codecov](https://img.shields.io/codecov/c/github/nschloe/fontman.svg?style=flat-square)](https://codecov.io/gh/nschloe/fontman)
[![LGTM](https://img.shields.io/lgtm/grade/python/github/nschloe/fontman.svg?style=flat-square)](https://lgtm.com/projects/g/nschloe/fontman)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)



### License
This software is published under the [MIT license](https://en.wikipedia.org/wiki/MIT_License).
